Index: src/core/SkLayerInfo.h |
diff --git a/src/core/SkLayerInfo.h b/src/core/SkLayerInfo.h |
index 5d598ef50a89f6bf73b05ebe25ff89ed425affd3..04ae1794a24fb808cc9b995364f08b7efb427682 100644 |
--- a/src/core/SkLayerInfo.h |
+++ b/src/core/SkLayerInfo.h |
@@ -18,7 +18,7 @@ public: |
// Information about a given saveLayer/restore block in an SkPicture |
class BlockInfo { |
public: |
- BlockInfo() : fPicture(NULL), fPaint(NULL), fKey(NULL), fKeySize(0) {} |
+ BlockInfo() : fPicture(nullptr), fPaint(nullptr), fKey(nullptr), fKeySize(0) {} |
~BlockInfo() { |
SkSafeUnref(fPicture); |
delete fPaint; |
@@ -27,8 +27,8 @@ public: |
// The picture owning the layer. If the owning picture is the top-most |
// one (i.e., the picture for which this SkLayerInfo was created) then |
// this pointer is NULL. If it is a nested picture then the pointer |
// is non-NULL and owns a ref on the picture. |
const SkPicture* fPicture; |
// The device space bounds of this layer. |
SkRect fBounds; |
@@ -46,7 +46,7 @@ public: |
// layer's top-left point to the origin (which must be part of the |
// initial matrix). |
SkMatrix fLocalMat; |
// The paint to use on restore. Can be NULL since it is optional. |
const SkPaint* fPaint; |
// The index of this saveLayer in the picture. |
size_t fSaveLayerOpID; |
@@ -27,8 +27,8 @@ public: |
// The picture owning the layer. If the owning picture is the top-most |
// one (i.e., the picture for which this SkLayerInfo was created) then |
- // this pointer is NULL. If it is a nested picture then the pointer |
- // is non-NULL and owns a ref on the picture. |
+ // this pointer is nullptr. If it is a nested picture then the pointer |
+ // is non-nullptr and owns a ref on the picture. |
const SkPicture* fPicture; |
// The device space bounds of this layer. |
@@ -46,7 +46,7 @@ public: |
// initial matrix). |
SkMatrix fLocalMat; |
- // The paint to use on restore. Can be NULL since it is optional. |
+ // The paint to use on restore. Can be nullptr since it is optional. |
const SkPaint* fPaint; |
// The index of this saveLayer in the picture. |